@@ -4,7 +4,7 @@ use strict;
 use warnings;
 
 # version
-our $VERSION = '0.1.4';
+our $VERSION = '0.1.5';
 
 # commands
 my $SVCS   = '/usr/bin/svcs';
@@ -408,7 +408,7 @@ sub setFMRIProperties {
     
     $self->addFMRI($fmri, $opts) if !$self->fmriExists($fmri, $opts);
     # extract property groups
-    my @pg = map { $properties->{$_}->{members} ? $_ : () } keys $properties;
+    my @pg = map { $properties->{$_}->{members} ? $_ : () } keys %$properties;
 
     for my $pg (@pg) {
         $self->addPropertyGroup($fmri, $pg, $properties->{$pg}->{type}, $opts);
